get file = 'hl.sav'.

compute kid18 = 0.
if (HL5 < 18) kid18 = 1.

aggregate outfile = 'tmp.sav'
  /break =  HH1 HH2
  /totkid18 = sum(kid18).

* open the aggregate file.
get file = 'tmp.sav'.

* sort the cases by cluster number and household number.
sort cases by HH1 HH2.

* save the sorted cases in a working file.
save outfile = 'tmp.sav'.

* open the household data file.
get file = 'hh.sav'.

* select completed households.
select if (HH9  = 1).

* sort the cases by cluster number and household number.
sort cases by HH1 HH2.

* merge the aggregate data onto the household data file.
match files
  /file = *
  /table = 'tmp.sav'
  /by  HH1 HH2.

weight by hhweight.

recode HH11 (1 = 1) (2,3 = 2) (4,5 = 3) (6,7 = 4) (8,9 = 5) (10 thru hi = 6) 
	into hhmember.
variable label hhmember "Nombre des membres du mnage".
value label hhmember
  1 "1"
  2 "2-3"
  3 "4-5"
  4 "6-7"
  5 "8-9"
  6 "10+".

recode totkid18 (0 = 0) (1 thru hi = 100) into kid18.
variable label kid18 "Au moins 1 enfant de moins de 18 ans".

recode HH14 (0 = 0) (1 thru hi = 100) into kid5.
variable label kid5 "Au moins 1 enfant de moins de 5 ans".

recode HH12 (0 = 0) (1 thru hi = 100) into woman.
variable label woman "Au moins 1 femme ge de 15-49 ans".

tables
  /format = zero
  /ftotal = tot1 "Total"
  /table = hhsex + HH7 + HH6+ HH6A + hhmember + tot1 by (statistics)
  /statistics =
    cpct(hhsex (f5.1) 'Pourcentage pondr')
    count(hhsex (f5.0) 'Nombre de mnages pondrs')
    unw count(hhsex (f5.0) 'Nombre de mnages non pondrs')
    cpct(HH7 (f5.1) 'Pourcentage pondr')
    count(HH7 (f5.0) 'Nombre de mnages pondrs')
    unw count(HH7 (f5.0) 'Nombre de mnages non pondrs')
    cpct(HH6 (f5.1) 'Pourcentage pondr')
    count(HH6 (f5.0) 'Nombre de mnages pondrs')
    unw count(HH6 (f5.0) 'Nombre de mnages non pondrs')
    cpct(HH6A (f5.1) 'Pourcentage pondr')
    count(HH6A (f5.0) 'Nombre de mnages pondrs')
    unw count(HH6A (f5.0) 'Nombre de mnages non pondrs')
    cpct(hhmember (f5.1) 'Pourcentage pondr')
    count(hhmember (f5.0) 'Nombre de mnages pondrs')
    unw count(hhmember (f5.0) 'Nombre de mnages non pondrs')
   /title =
     "Tableau HH.3: Composition du mnage : Pourcentage des mnages selon certaines caractristiques socio-dmographiques, Cte d'Ivoire, 2006".


tables
  /format = zero
  /observation = kid18 kid5 woman
  /table = kid18 + kid5 + woman by (statistics)
  /statistics =
    mean(kid18 (f5.1) 'Pourcentage pondr')
    validn(kid18 (f5.0) 'Nombre de mnages pondrs')
    unw validn(kid18 (f5.0) 'Nombre de mnages non pondrs')
    mean(kid5 (f5.1) 'Pourcentage pondr')
    validn(kid5 (f5.0) 'Nombre de mnages pondrs')
    unw validn(kid5 (f5.0) 'Nombre de mnages non pondrs')
    mean(woman (f5.1) 'Pourcentage pondr')
    validn(woman (f5.0) 'Nombre de mnages pondrs')
    unw validn(woman (f5.0) 'Nombre de mnages non pondrs')
  /title =
     "Tableau HH.3: Composition du mnage : Pourcentage des mnages selon certaines caractristiques socio-dmographiques, Cte d'Ivoire, 2006".

new file.

erase file = 'tmp.sav'.
