get file = "hl.sav".

sort cases by HH1 HH2 HL1.

save out="tmp.sav"
 /keep HH1, HH2, HL1, HL5, HL4, melevel
 /rename (HL1 = CD11).

get file = "hh.sav".

select if (HH9 = 1).

* select households in which child discipline questionnaire was administered.
select if (not sysmis(CD12A)).

sort cases by HH1 HH2 CD11.

match files
  /file = *
  /table = "tmp.sav"
  /by HH1 HH2 CD11.

* To analyze only for children selected use just hhweight.
weight by hhweight.
* To analyze for all children age 2-14 years, weight by hhweight * CD7.
 *compute newwgt = hhweight*CD7.
 *weight by newwgt.

select if (HL5 >= 2 and HL5 <= 14).

recode HL5 (2 thru 4 = 1) (5 thru 9 = 2) (10 thru 14 = 3) into agegrp.
variable label agegrp "Age".
value label agegrp
  1 "2-4 ans"
  2 "5-9 ans"
  3 "10-14 ans".

compute nviolent = 0.
if ((CD12A = 1 or CD12B = 1 or CD12E = 1) and CD12C = 2 and CD12D = 2 and
  CD12F = 2 and CD12G = 2 and CD12H = 2 and CD12I = 2 and CD12J = 2 and 
	CD12K = 2) nviolent = 100.
variable label nviolent "des punitions non violentes".

compute punish = 0.
if (CD12D = 1 or CD12H = 1) punish = 100.
variable label punish "des violences (ou punitions) psychologiques".

compute minor = 0.
if (CD12C = 1 or CD12F = 1 or CD12G = 1 or CD12J = 1) minor = 100.
variable label minor "Punition physique mineure".

compute severep = 0.
if (CD12I = 1 or CD12K = 1) severep = 100.
variable label Severep "Punition physique svre".
compute any = 0.
if (punish = 100 or minor = 100 or severep = 100) any = 100.
variable label any "Toute punition psychologique ou physique*".

compute ndisvio = 0.
if (CD12A = 2 and CD12B = 2 and CD12C = 2 and CD12D = 2 and CD12E = 2 and
  CD12F = 2 and CD12G = 2 and CD12H = 2 and CD12I = 2 and CD12J = 2 and 
	CD12K = 2) ndisvio = 100.
variable label ndisvio "Pas de discipline ou punition".

compute cdmiss = 0.
if (nviolent = 0 & any = 0 & ndisvio = 0) cdmiss = 100.
variable label cdmiss "Manquant".

compute ppunish = 0.
if (CD13 = 1) ppunish = 100.
variable label ppunish "Mre/Tutrice crot que l'enfant mrite d'tre puni physiquement".

compute layer = 0.
variable label layer "".
value label layer 0 "Pourcentage d'enfants gs de 2-14 ans qui ont subi: :".

tables
  /format = zero
  /observation = nviolent punish minor severep any ndisvio cdmiss ppunish 
  /ftotal = tot1 "Total" tot2 "Nombre d'enfants gs de 2-14 ans**"
  /table = HL4 + HH7 + HH6+ HH6A + agegrp + melevel + wlthind5  + tot1 by 
	  layer > (nviolent + punish + minor + severep + any + ndisvio + cdmiss) + ppunish + tot2
  /statistics
    mean(nviolent (f5.1) '')
    mean(punish (f5.1) '')
    mean(minor (f5.1) '')
    mean(severep (f5.1) '')
    mean(any (f5.1) '')
    mean(ndisvio (f5.1) '')
    mean(ppunish (f5.1) '')
    mean(cdmiss (f5.1) '')
    count(tot2 (f5.0) '')
  /title
    "Tableau CP.4: Pourcentage d'enfants de 2-14 ans selon la mthode de discipline de l'enfant, Cte d'Ivoire, 2006"
  /caption                                                                                                                                                                          
    "* MICS Indicateur 74"
       "Le tableau repose sur les enfants de 2-14 ans slectionns au hasard pendant le travail sur le terrain pour lesquels les questions sur la discipline de l'enfant est administr".

*new file.

* delete working files.
*erase file = 'tmp.sav'.

