get file = 'hl.sav'.

weight by hhweight.

compute total  = 1.
variable label total "Number of children 10-14 years of age".

recode HL5 (0 thru 4 = 1) (5 thru 9 = 2) (10 thru 14 = 3) (15 thru 17 =4) into agegrp.
variable label agegrp "Age".
value label agegrp
  1 "0-4 years"
  2 "5-9 years"
  3 "10-14 years"
  4 "15-17 years".

compute mfdead = 0.
if (HL9 = 2 and HL11 = 2) mfdead = 100.
variable label mfdead "Percent of children whose mother and father have died".

compute school = 0.
if (ED4 = 1) school = 100.
variable label school "Attending school".

do if (mfdead = 100).
+ compute school1 = 0.
+ if (school = 100) school1 = 100.
+ compute tschool1 = 0.
+ if (school = 100) tschool1 = 1.
end if.
variable label  school1 "School attendance rate of children whose mother and father have died".

compute liveone = 0.
if (HL9 = 1 and HL11 = 1 and (HL10 <> 0 or HL12 <> 0)) liveone = 100.
variable label liveone "Non-orphans living with at least one parent".

do if (liveone = 100).
+ compute school2 = 0.
+ if (school = 100) school2 = 100.
+ compute tschool2 = 0.
+ if (school2 = 100) tschool2 = 1.
end if.
variable label school2 "School attendance rate of children of whom both parent are alive and child is living with at least one parent".

compute oneboth = 0.
if (HL9 = 2 or HL11 = 2) oneboth = 100.
variable label oneboth "One or both parents dead **".

select if (HL5 >= 10 and HL5 <= 14).

compute total = 1.

aggregate outfile = 'tmp1.sav'
  /break HL4
  /tot1  = mean(oneboth)
  /tot2  = mean(mfdead)
  /tot2a = sum(mfdead)
  /tot3  = mean(school1)
  /tot3a = sum(tschool1)
  /tot4  = mean(liveone)
  /tot5  = mean(school2)
  /tot5a = sum(tschool2)
  /tot10 = sum(total).

aggregate outfile = 'tmp2.sav'
  /break HH7
  /tot1  = mean(oneboth)
  /tot2  = mean(mfdead)
  /tot2a = sum(mfdead)
  /tot3  = mean(school1)
  /tot3a = sum(tschool1)
  /tot4  = mean(liveone)
  /tot5  = mean(school2)
  /tot5a = sum(tschool2)
  /tot10 = sum(total).

aggregate outfile = 'tmp3.sav'
  /break HH6
  /tot1  = mean(oneboth)
  /tot2  = mean(mfdead)
  /tot2a = sum(mfdead)
  /tot3  = mean(school1)
  /tot3a = sum(tschool1)
  /tot4  = mean(liveone)
  /tot5  = mean(school2)
  /tot5a = sum(tschool2)
  /tot10 = sum(total).

aggregate outfile = 'tmp4.sav'
  /break wlthind5
  /tot1  = mean(oneboth)
  /tot2  = mean(mfdead)
  /tot2a = sum(mfdead)
  /tot3  = mean(school1)
  /tot3a = sum(tschool1)
  /tot4  = mean(liveone)
  /tot5  = mean(school2)
  /tot5a = sum(tschool2)
  /tot10 = sum(total).

aggregate outfile = 'tmp5.sav'
  /break total
  /tot1  = mean(oneboth)
  /tot2  = mean(mfdead)
  /tot2a = sum(mfdead)
  /tot3  = mean(school1)
  /tot3a = sum(tschool1)
  /tot4  = mean(liveone)
  /tot5  = mean(school2)
  /tot5a = sum(tschool2)
  /tot10 = sum(total).

get file = 'tmp1.sav'.

add files
  /file = *
  /file = 'tmp2.sav'
  /file = 'tmp3.sav'
  /file = 'tmp4.sav'
  /file = 'tmp5.sav'.

variable label tot1 "L'un ou les deux parents sont dcds".
variable label tot2 "Pourcentage d'enfants dont les parents sont dcds".
variable label tot2a "Nombre d'enfants dont les parents sont dcds".
variable label tot3 "Taux de frquentation scolaire des enfants dont les parents sont dcds".
variable label tot3a "Nombre d'enfants dont les parents dcds sont dcds et qui frquentent l'cole".
variable label tot4 "Pourcentage d'enfants dont les deux parents sont en vie, l'enfant vivant avec au moins l'un d'eux".
variable label tot5 "Taux de frquentation scolaire des enfants dont les deux parents sont en vie, l'enfant vivant avec au moins l'un d'eux".
variable label tot5a "Nombre d'enfants dont les parents sont vivants et dont l'enfant vit avec au moinsl'un des parents et qui frquente l'cole".
variable label tot10 "Total des enfants gs de 10-14 ans".

compute ratio1 = tot3/tot5.
variable label ratio1 "Taux de frquentation des orphlins de pre et de mre par rapport aux non-orphlins*".

tables
  /format = zero
  /observation =tot3 tot4 tot5 ratio1 tot10 
  /ftotal = tot1a "Total" 
  /table = HL4 + HH7 + HH6 + wlthind5 + tot1a by 
    tot3 + tot4 + tot5 + ratio1 + tot10 
  /statistics
    mean(tot3 (f5.1) '')
    mean(tot4 (f5.1) '')
    mean(tot5 (f5.1) '')
    mean(ratio1 (f5.2) '')
    sum(tot10 (f5.0) '')
  /title
    "Tableau HA.12: Frquentation scolaire des enfants de 10-14 ans en fonction de leur tat "+
		"d'orphlins, Cte d'Ivoire, 2006"
  /caption
    "* MICS Indicateur 77; MDG Indicateur 20".

new file.

*delete working files.
erase file = 'tmp1.sav'.
erase file = 'tmp2.sav'.
erase file = 'tmp3.sav'.
erase file = 'tmp4.sav'.
erase file = 'tmp5.sav'.

