*open the household listing data file.
get file = 'hl.sav'.

* create a variable that will reflect mother's line number.
compute mline = hl1

* create what will be mother's education level.
*recode ED3A (1 = 2) (2,3 = 3) (6 = 4) (8,9 = 9) (else = 1) into melevel.
*variable label melevel "Education de la mre".
*value label melevel
*  1 "Aucune"
 * 2 "Primaire"
  *3 "Secondaire et +"
*  4 "Programme non formel"
 * 5 "Mre non dans le mnage"
*  9 "Manquant/Ne sait pas".
*format melevel (f1.0).

* education level.
***recode ED3A  (1 = 2) (2,3 = 3) (6 = 4) (8,9 = 9) (else = 1) into melevel.
recode ED3A (1 = 2) (2,3 = 3) (6 = 4) (8,9 = 9) (else = 1) into melevel.
variable label melevel "Education de la mre".
value label melevel
  1 "Aucun"
  2 "Primaire"
  3 "Secondaire et +"
  4 "Programme non formel"
  5 "Mre non dans le mnage"
  9 "Manquant/Ne sait pas".
format melevel (f1.0).

* sort the cases by cluster number, household number and mother's line number.
sort cases by HH1 HH2 mline.

* save a mother's education file.
save outfile = 'tmpme.sav'
  /keep HH1 HH2 mline melevel.

* create a variable that will reflect father's line number.
compute fline = hl1

* create what will be father's education level.
recode ED3A (1 = 2) (2,3 = 3) (6 = 4) (8,9 = 9) (else = 1) into felevel.
variable label felevel "Education du pre".
value label felevel
  1 "Aucun"
  2 "Primaire"
  3 "Secondaire et +"
  4 "Programme non formel"
  5 "Pre non dans le mnage"
  9 "Manquant/Ne sait pas".
format felevel (f1.0).

* sort the cases by cluster number, household number and father's line number.
sort cases by HH1 HH2 fline.

* save a father's education file.
save outfile = 'tmpfe.sav'
  /keep HH1 HH2 fline felevel.

* keep heads of household only.
select if (hl3 = 1).

* create head of household's education level.
recode ED3A (1 = 2) (2,3 = 3) (6 = 4) (8,9 = 9) (else = 1) into helevel.
variable label helevel "Education du chef de mnage".
value label helevel
  1 "Aucun"
  2 "Primaire"
  3 "Secondaire et +"
  4 "Programme non formel"
  9 "Manquant/Ne sait pas".
format helevel (f1.0).

* sort the cases by cluster number, household number and head's line number.
sort cases by HH1 HH2 HL1.

* save a household head's education file.
save outfile = 'tmphhe.sav'
  /keep HH1 HH2 HL1 helevel.

* open the household listing data file.
get file = 'hl.sav'.

* compute mother's line number for household members aged 17 or younger.
if (HL7 <> 0) mline = HL7.
if (HL8 <> 0) mline = HL8.
if (hl5 < 18 and sysmis(mline)) mline = 0.
* use mother's line number if mother/caretaker from HL7 & HL8 is not available.
if (mline=0 and not sysmis(HL10) and HL10 <> 0) mline = HL10.
variable label mline "Numro de ligne de la mre".
format mline (f2.0).

* sort the cases by cluster number, household number and mother's line number.
sort cases by HH1 HH2 mline.

* merge the mother's education file onto the household listing file.
match files
  /file = *
  /table = 'tmpme.sav'
  /by HH1 HH2 mline.

* recode mother's education level to deal with mothers who live elsewhere or are dead.
if (mline = 0) melevel = 5.

* compute father's line number for household members aged 17 or younger.
compute fline = HL12.
if (hl5 < 18 and sysmis(fline)) fline = 0.
variable label fline "Numro de ligne du pre".
format fline (f2.0).

* sort the cases by cluster number, household number and father's line number.
sort cases by HH1 HH2 fline.

* merge the father's education file onto the household listing file.
match files
  /file = *
  /table = 'tmpfe.sav'
  /by HH1 HH2 fline.

* recode father's education level to deal with fathers who live elsewhere or are dead.
if (fline = 0) felevel = 5.

* sort the cases by cluster number and household number.
sort cases by HH1 HH2.

* merge the household head file onto the household listing file.
match files
  /file = *
  /table = 'tmphhe.sav'
  /by HH1 HH2 .

* sort the cases by cluster number, household number and line number.
sort cases by HH1 HH2 HL1 .


VAR LAB hc1c 'Ethnie ou Nationalit'.
VAL LAB hc1c
 101 "Abbey"
 102 "Abidji"
 103 "Abour"
 104 "Abron"
 105 "Adjoukrou"
 106 "Agni"
 107 "Ahizi"
 108 "Alladian"
 109 "Appolo ou N'zima"
 110 "Aky ou Atti"
 111 "Avikam ou Brignan"
 114 "Baoul"
 122 "Doma"
 123 "Ebri"
 124 "Ega"
 125 "Ehotil"
 126 "Essouma"
 144 "Krobou"
 150 "M'batto (goua)"
 154 "N'gain"
 169 "Yaour (yohour)"
 112 "Bakw"
 115 "Bt"
 119 "Dida"
 130 "Gnaboua (niaboua)"
 131 "Godi"
 132 "Gouin ou Kirma"
 134 "Gur"
 136 "Kodia"
 139 "Kotrohou"
 141 "Kouya"
 142 "Kouzi"
 145 "Kroumen"
 153 "Nyo"
 155 "Nidboua"
 159 "Oubi"
 166 "Wan"
 167 "Wob"
 113 "Bambara"
 120 "Dioula"
 127 "Foula"
 129 "Gbin"
 135 "Kamara ou Komara"
 138 "Koro"
 143 "Kouyaka ou koyara"
 148 "Mahou ou Mahouka"
 149 "Malink ou Maninka"
 156 "Nigbi"
 157 "Ouadougou"
 160 "Ouodougou"
 128 "Gagou"
 133 "Gouro"
 151 "Mona ou Mouan"
 158 "Ouan"
 165 "Toura"
 168 "Yacouba ou Dan"
 116 "Birifor"
 117 "Conja"
 118 "Dgha"
 121 "Djimini"
 137 "Komono"
 140 "Koulango"
 146 "Lobi"
 147 "Lohron"
 152 "Nafana"
 161 "Samogho"
 162 "Snoufo"
 163 "Siti"
 164 "Tagouana"
 170 "Naturaliss Ivoiriens"
 171 "Ivoiriens sans prcision"
 201 "Bnin"
 202 "Burkina Faso"
 206 "Ghana"
 207 "Guine"
 208 "Guine Bissau"
 209 "Libria"
 210 "Mali"
 211 "Mauritanie"
 212 "Niger"
 213 "Nigria"
 214 "Sngal"
 216 "Togo"
 243 "Congo Brazzaville"
 244 "Republique Dmocratique du Congo (RDC)"
 248 "Tchad"
 299 "Non Dclar".

* groupe grpethniq.
recode hc1c (101 102 103 104 105 106 107 108 109 110 111 114 122 123 124 125 126 144 150 154 169 =1)
                       (112 115 119 130 131 132 134 136 139 141 142 145 153 155 159 166 167=2)
                      (113 120 127 129 135 138 143 148 149 156 157 160 = 3) (128 133 151 158 165 168 = 4)
                     (116 117 118 121 137 140 146 147 152 161 162 163 164 = 5) (170=6) (171 199=7) 
                     (201 202  243 206  207 208 244 209 210 211 212 213 214 248 216 299= 8)  into hc1cee.

VAR LAB hc1cee 'Groupe ethnique du chef de mnage'.
VAL LAB hc1cee
 1 "Akan"
 2 "Krou"
 3 "Mand du Nord"
 4 "Mand du Sud"
 5 "Voltaque/Gur"
 6 "Naturaliss ivoiriens"
 7 "Ivoiriens sans prcision"
 8 "Non Ivoiriens".


* save the household listing data file.
save outfile = 'hl.sav'.

* erase the working files.
erase file = 'tmpme.sav'.
erase file = 'tmpfe.sav'.
erase file = 'tmphhe.sav'.
